@@ -17,6 +17,9 @@
 #          add frameNumber and check colume-fields location
 # v0.1.3 : 2021/05/06 revise dataFrame dtype
 #
+# v0.1.4 : 2021/10/12 doppler and range swap
+#          the sequence is eadrs: elv, azimuth,doppler,range and snr
+#
 import serial
 import time
 import struct
@@ -52,8 +55,8 @@ class Pc3:
 	frameNumber = 0
 	# provide csv file dataframe
 	# real-time 
-	
-	v6_col_names_rt = ['fN','type','elv','azimuth','range' ,'doppler','snr',  'sx', 'sy', 'sz' ]
+    #v6_col_names_rt = ['time','fN','type','elv','azimuth','range' ,'doppler','snr','sx', 'sy', 'sz'] # original
+	v6_col_names_rt = ['fN','type','elv','azimuth','doppler','range' ,'snr',  'sx', 'sy', 'sz' ]  #v0.1.4
 	v7_col_names_rt = ['fN','type','posX','posY','velX',      'velY','accX','accY','posZ','velZ','accZ','tid']
 	v8_col_names_rt = ['fN','type','targetID']
 	 
@@ -210,7 +213,7 @@ class Pc3:
 			except:
 				#return (False,v6,v7,v8)
 				#return (False,v6,v7,v8) if (df == None) else self.list2df(False,v6,v7,v8)
-				return self.list2df(False,v6,v7,v8) if (df == 'DataFrame') else (False,v6,v7,v8)
+				return self.list2df(False,v6df,v7df,v8df) if (df == 'DataFrame') else (False,v6,v7,v8)
 				
 			#print(str(ch))
 			if lstate == 'idle':
