@@ -20,7 +20,8 @@
 #           v7 dataframe:'tid' move to front of 'ec0'
 # v1.0.0 : 2022/07/18
 #           add tilt and install and sx,sy,sz in raw data mode
-
+# v1.0.2 : v6 raw data: (elv,azi,ran,dop,snr,sx,sy,sz)..
+#
 import serial
 import time
 import struct
@@ -54,6 +55,9 @@ class Pc3OVH:
 	height = 0.0
 	hdr = header
 	u = unitS
+	start_time = 0
+	v6_fetch_time = 0
+	frameNumber = 0
 	
 	# provide csv file dataframe
 	# real-time 
@@ -83,12 +87,12 @@ class Pc3OVH:
 		self.height = 0.0 if height == None else height
 		self.elv_tilt = 0.0 if tiltAngle == None else tiltAngle * np.pi/180.0 
 		print("(jb)OverHead People Counting 3D initial")
-		print("(jb)version:v1.0.0")
+		print("(jb)version:v1.0.2")
 		print("(jb)For Hardware:Batman-201(ISK) & BM-501 (AOP)")
 		print("(jb)Hardware: IWR-6843 & AOP")
 		print("(jb)Firmware: PC3-I471")
 		print("(jb)UART Baud Rate:921600")
-		print(f"(jb)Radar tilt degree:{tiltAngle}°")
+		print(f"(jb)Radar tilt degree:{tiltAngle}° install height:{height}")
 		print("Output: V6,V7,V8 data:(RAW)")
 		
 	def useDebug(self,ft):
@@ -205,8 +209,6 @@ class Pc3OVH:
 		v7df = ([])
 		v8df = ([])
 		 
-		
-		
 		while True:
 			try:
 				ch = self.port.read()
@@ -226,6 +228,8 @@ class Pc3OVH:
 						lstate = 'header'
 						rangeProfile = b""
 						sbuf = b""
+						self.start_time = time.time()
+						 
 				else:
 					#print("not: magicWord state:")
 					idx = 0
@@ -371,7 +375,8 @@ class Pc3OVH:
 							#v6df.append((self.hdr.frameNumber,'v6',elv,azi,dop,ran,snr,sx,sy,sz)) #v0.1.0
 							v6df.append((self.hdr.frameNumber,'v6',elv,azi,ran,dop,snr,sx,sy,sz)) #v0.1.1 
 						else:
-							v6.append((elv,azi,dop,ran,snr,sx,sy,sz))
+							#v6.append((elv,azi,dop,ran,snr,sx,sy,sz))
+							v6.append((elv,azi,ran,dop,snr,sx,sy,sz)) #v1.0.2
 						
 						#print("point_cloud_2d.append:[{:d}]".format(len(point_cloud_2d)))
 						sbuf = b""
@@ -394,6 +399,7 @@ class Pc3OVH:
 							print("(V6:{:d})=>(idle) :true".format(tlvCount))
 						#return (True,v6,v7,v8)
 						#return (True,v6,v7,v8) if (df == None) else self.list2df(True,v6df,v7df,v8df)
+						self.v6_fetch_time  = (time.time() - self.start_time) * 1000 
 						return self.list2df(True,v6df,v7df,v8df) if (df == 'DataFrame') else (True,v6,v7,v8)
 						
 					else: # Go to TL to get others type value
