@@ -22,7 +22,10 @@
 #          pc3_v2: add ec[16],g,confidenceLevel
 #          this version lib same as pc3OVH 
 #
-# v2.0.1: 2022/06/10
+# v2.0.1: 2022/06/10 v6 add sx,sy,sz
+#
+# v2.0.2: 2022/06/13 added azimuth offset
+#                    azi_offset
 #
 
 import serial
@@ -57,6 +60,8 @@ class Pc3_v2:
 	port = ""
 	hdr = header
 	u = unitS
+	frameNumber = 0
+	azi_offset = 0.0
 	
 	# provide csv file dataframe
 	# real-time 
@@ -81,8 +86,10 @@ class Pc3_v2:
 	sm  = False #Observed StateMachine: True Show message
 	plen = 16 
 	
-	def __init__(self,port):
+	def __init__(self,port, degree = None):
 		self.port = port
+		self.azi_offset = 0.0 if degree == None else degree * 3.14159/180.0
+		
 		print("(jb)People Counting 3D v2.0 (Wall Mount) initial")
 		print("(jb)vsersion:v2.0")
 		print("(jb)For Hardware:Batman-201(ISK) & BM-501 (AOP)")
@@ -345,7 +352,7 @@ class Pc3_v2:
 						#print(":".join("{:02x}".format(c) for c in sbuf))
 						(e,a,d,r,s) = struct.unpack('2b3h', sbuf)
 						elv = e * self.u.elevationUnit
-						azi = a * self.u.azimuthUnit
+						azi = a * self.u.azimuthUnit + self.azi_offset
 						dop = d * self.u.dopplerUnit
 						ran = r * self.u.rangeUnit
 						snr = s * self.u.snrUnit
